/**
 * @name NsLink.tsx
 * @description Exports one components - NsLink
 */

import React, {
    PropsWithChildren,
    ReactElement,
} from 'react';

import {
    StyledLink,
    StyledNextLink,
} from './NsLink.styled';
import { NsLinkProps } from './types.d';
import { NsTypography } from '../typography';
import { NsIcon } from '../icon';
import { styled } from '@nuskin/foundation-theme';

export const SecondaryLinkWrapper = styled.a`
    display: flex;
    justify-content: center; /* Centers content horizontally */
    align-items: center; 
    text-align: center;
    padding: 8px 16px; /* Padding for the link */
    text-decoration: none; /* Removes default underline */
    svg {
        margin-right: 10px;
        margin-left: 10px;
        g {
            stroke-width: 2;
        }
    }
    .cta-text {
        text-decoration: underline;
        text-underline-offset: 4px;
        text-decoration-color: inherit;
    }
    :hover {
        opacity: 0.7;
    }
`;

const SecondaryWrapper: React.FC<{
    href: string;
    variants: string;
    fontColor: 'primary' | 'secondary' | undefined;
    children: React.ReactNode;
}> = ({ href, variants, fontColor, children }) => {
    return (
        <SecondaryLinkWrapper href={href}>
            <NsTypography  variant="body-l" className="!m-0 cta-text" weight="bold" color={fontColor || 'primary'}>
                {children}
            </NsTypography>
            <NsIcon name="arrowRight" size="small" className="icon-order" color={fontColor} />
        </SecondaryLinkWrapper>
    );
};

const NsLink = (props: PropsWithChildren<NsLinkProps>): ReactElement => {
    const {
        className,
        href,
        variants,
        outlined,
        underlineOnHover,
        target,
        isSsr = false,
        additionalProps,
        children,
        passHref,
        prefetch,
        disabled,
        showHorizontal,
        color,
    } = props;

    if (isSsr) {
        return (
            <StyledNextLink
                className={className}
                href={href}
                variants={variants}
                outlined={outlined}
                showHorizontal={showHorizontal}
                fontColor={color}
                $underlineOnHover={underlineOnHover}
                passHref={passHref}
                prefetch={prefetch}
                disabled={disabled}
                {...additionalProps}
            >
                {children}
            </StyledNextLink>
        );
    }

    return (
        <StyledLink
            className={className}
            href={href}
            variants={variants}
            outlined={outlined}
            showHorizontal={showHorizontal}
            fontColor={color}
            disabled={disabled}
            $underlineOnHover={underlineOnHover}
            target={target}
            {...additionalProps}
        >
            {variants === 'secondary' ? ( // secondary condition
                <SecondaryWrapper href={href} variants={variants} fontColor={color}>
                    {children}
                </SecondaryWrapper>
            ) : (
                children
            )}
        </StyledLink>
    );
};

export default NsLink;
